@@ -18,14 +18,14 @@ protected:
 
   virtual void on_print(int a);
   
-  using type_signal_print = sigc::signal<void, int>;
+  using type_signal_print = sigc::signal<void(int)>;
   type_signal_print signal_print;
     
 };
 
 Something::Something()
 {
-  auto iter = signal_print.connect( sigc::mem_fun(this, &Something::on_print) );
+  auto iter = signal_print.connect( sigc::mem_fun(*this, &Something::on_print) );
 
   signal_print.emit(2);
 
