@@ -83,7 +83,7 @@ void connection::disconnect()
     slot_->disconnect(); // This notifies slot_'s parent.
 } 
 
-connection::operator bool() noexcept
+connection::operator bool() const noexcept
 {
   return !empty();
 }
@@ -99,11 +99,10 @@ void connection::set_slot(slot_base* sl)
     slot_->add_destroy_notify_callback(this, &notify);
 }
 
-void* connection::notify(void* data)
+void connection::notify(notifiable* data)
 {
   auto self = reinterpret_cast<connection*>(data);
   self->slot_ = nullptr;
-  return nullptr;
 }
 
 } /* namespace sigc */
