@@ -24,7 +24,7 @@ namespace internal {
 // Data sent from signal_impl::insert() to slot_rep::set_parent() when a slot is
 // connected, and then sent from slot_rep::disconnect() to signal_impl::notify()
 // when the slot is disconnected. Bug 167714.
-struct self_and_iter
+struct self_and_iter : public notifiable
 {
   signal_impl* self_;
   signal_impl::iterator_type iter_;
@@ -37,6 +37,19 @@ signal_impl::signal_impl()
 : ref_count_(0), exec_count_(0), deferred_(false)
 {}
 
+signal_impl::~signal_impl()
+{
+  // unreference() must not call ~signal_impl() while clear() is executing.
+  ++ref_count_;
+
+  // Disconnect all slots before *this is deleted.
+  clear();
+
+  // Now ref_count_ can be cleared again (not really necessary), but don't do it
+  // with a call to unreference(). That would invoke ~signal_impl() recursively.
+  --ref_count_;
+}
+
 // only MSVC needs this to guarantee that all new/delete are executed from the DLL module
 #ifdef SIGC_NEW_DELETE_IN_LIBRARY_ONLY
 void* signal_impl::operator new(size_t size_)
@@ -149,7 +162,7 @@ void signal_impl::sweep()
 }
 
 //static
-void* signal_impl::notify(void* d)
+void signal_impl::notify(notifiable* d)
 {
   std::unique_ptr<self_and_iter> si(static_cast<self_and_iter*>(d));
 
@@ -163,7 +176,7 @@ void* signal_impl::notify(void* d)
   }
   else                           // This is occuring during signal emission or slot erasure.
     si->self_->deferred_ = true; // => sweep() will be called from ~signal_exec() after signal emission.
-  return nullptr;                // This is safer because we don't have to care about our
+                                 // This is safer because we don't have to care about our
                                  // iterators in emit(), clear(), and erase().
 }
 
@@ -191,11 +204,6 @@ signal_base::~signal_base()
 {
   if (impl_)
   {
-    // Disconnect all slots before impl_ is deleted.
-    // TODO: Move the signal_impl::clear() call to ~signal_impl() when ABI can be broken.
-    if (impl_->ref_count_ == 1)
-      impl_->clear();
-
     impl_->unreference();
   }
 }
@@ -259,13 +267,9 @@ signal_base& signal_base::operator=(const signal_base& src)
 
   if (impl_)
   {
-    // Disconnect all slots before impl_ is deleted.
-    // TODO: Move the signal_impl::clear() call to ~signal_impl() when ABI can be broken.
-    if (impl_->ref_count_ == 1)
-      impl_->clear();
-
     impl_->unreference();
   }
+
   impl_ = src.impl();
   impl_->reference();
   return *this;
@@ -277,11 +281,6 @@ signal_base& signal_base::operator=(signal_base&& src)
 
   if (impl_)
   {
-    // Disconnect all slots before impl_ is deleted.
-    // TODO: Move the signal_impl::clear() call to ~signal_impl() when ABI can be broken.
-    if (impl_->ref_count_ == 1)
-      impl_->clear();
-
     impl_->unreference();
   }
 
