@@ -19,7 +19,7 @@
 #ifndef _SIGC_TYPE_TRAIT_H_
 #define _SIGC_TYPE_TRAIT_H_
 
-#include <sigc++config.h> //To get SIGC_SELF_REFERENCE_IN_MEMBER_INITIALIZATION
+#include <sigc++config.h>
 
 
 namespace sigc {
@@ -27,48 +27,44 @@ namespace sigc {
 template <class T_type>
 struct type_trait
 {
-  typedef T_type  type;
-  typedef T_type& pass;
-  typedef const T_type& take;
-  typedef T_type* pointer;
+  using pass = T_type&;
+  using take = const T_type&;
 };
 
 template <class T_type, int N>
 struct type_trait<T_type[N]>
 {
-  typedef T_type*  type;
-  typedef T_type*& pass;
-  typedef const T_type*& take;
-  typedef T_type** pointer;
+  using pass = T_type*&;
+  using take = const T_type*&;
 };
 
 template <class T_type>
 struct type_trait<T_type&>
 {
-  typedef T_type  type;
-  typedef T_type& pass;
-  typedef T_type& take;
-  typedef T_type* pointer;
+  using pass = T_type&;
+  using take = T_type&;
 };
 
 template <class T_type>
 struct type_trait<const T_type&>
 {
-  typedef const T_type  type;
-  typedef const T_type& pass;
-  typedef const T_type& take;
-  typedef const T_type* pointer;
+  using pass = const T_type&;
+  using take = const T_type&;
 };
 
 template<>
 struct type_trait<void>
 {
-  typedef void  type;
-  typedef void  pass;
-  typedef void  take;
-  typedef void* pointer;
+  using pass = void;
+  using take = void;
 };
 
+template<typename T>
+using type_trait_pass_t = typename type_trait<T>::pass;
+
+template<typename T>
+using type_trait_take_t = typename type_trait<T>::take;
+
 } /* namespace sigc */
 
 #endif /* _SIGC_TYPE_TRAIT_H_ */
