@@ -25,38 +25,38 @@ public:
 
 void test_member_method_is_const()
 {
-  static_assert(!sigc::member_method_is_const<decltype(&Something::some_func)>::value,
+  static_assert(!sigc::internal::member_method_is_const<decltype(&Something::some_func)>::value,
     "member_method_is_const failed to identify a non-const member method.");
 
-  static_assert(!sigc::member_method_is_const<decltype(&Something::some_volatile_func)>::value,
+  static_assert(!sigc::internal::member_method_is_const<decltype(&Something::some_volatile_func)>::value,
     "member_method_is_const failed to identify a non-const member method.");
 
-  static_assert(sigc::member_method_is_const<decltype(&Something::some_const_func)>::value,
+  static_assert(sigc::internal::member_method_is_const<decltype(&Something::some_const_func)>::value,
     "member_method_is_const failed to identify a const member method.");
 
-  static_assert(sigc::member_method_is_const<decltype(&Something::some_const_volatile_func)>::value,
+  static_assert(sigc::internal::member_method_is_const<decltype(&Something::some_const_volatile_func)>::value,
     "member_method_is_const failed to identify a const member method.");
 }
 
 void test_member_method_is_volatile()
 {
-  static_assert(!sigc::member_method_is_volatile<decltype(&Something::some_func)>::value,
+  static_assert(!sigc::internal::member_method_is_volatile<decltype(&Something::some_func)>::value,
     "member_method_is_const failed to identify a non-volatile member method.");
 
-  static_assert(!sigc::member_method_is_volatile<decltype(&Something::some_const_func)>::value,
+  static_assert(!sigc::internal::member_method_is_volatile<decltype(&Something::some_const_func)>::value,
     "member_method_is_const failed to identify a non-volatile member method.");
 
-  static_assert(sigc::member_method_is_volatile<decltype(&Something::some_volatile_func)>::value,
+  static_assert(sigc::internal::member_method_is_volatile<decltype(&Something::some_volatile_func)>::value,
     "member_method_is_const failed to identify a volatile member method.");
 
-  static_assert(sigc::member_method_is_volatile<decltype(&Something::some_const_volatile_func)>::value,
+  static_assert(sigc::internal::member_method_is_volatile<decltype(&Something::some_const_volatile_func)>::value,
     "member_method_is_const failed to identify a volatile member method.");
 }
 
 void test_member_method_class_type()
 {
   static_assert(std::is_same<
-    sigc::member_method_class<decltype(&Something::some_func)>::type,
+    sigc::internal::member_method_class<decltype(&Something::some_func)>::type,
     Something>::value,
     "member_method_class_type failed to identify the class type.");
 }
@@ -64,12 +64,12 @@ void test_member_method_class_type()
 void test_member_method_result_type()
 {
   static_assert(std::is_same<
-    sigc::member_method_result<decltype(&Something::some_int_func)>::type,
+    sigc::internal::member_method_result<decltype(&Something::some_int_func)>::type,
     int>::value,
     "member_method_result_type failed to identify the result type.");
 
   static_assert(std::is_same<
-    sigc::member_method_result<decltype(&Something::some_bool_func)>::type,
+    sigc::internal::member_method_result<decltype(&Something::some_bool_func)>::type,
     bool>::value,
     "member_method_result_type failed to identify the result type.");
 }
