@@ -33,9 +33,9 @@ int main(int argc, char* argv[])
     std::cout << "sizes of public classes:" << std::endl;
 
     std::cout << "  trackable:               " << sizeof(sigc::trackable) << std::endl;
-    std::cout << "  slot<void>:              " << sizeof(sigc::slot<void>) << std::endl;
-    std::cout << "  signal<void>:            " << sizeof(sigc::signal<void>) << std::endl;
-    std::cout << "  signal<void>::iterator:  " << sizeof(sigc::signal<void>::iterator) << std::endl;
+    std::cout << "  slot<void()>:              " << sizeof(sigc::slot<void()>) << std::endl;
+    std::cout << "  signal<void()>:            " << sizeof(sigc::signal<void()>) << std::endl;
+    std::cout << "  signal<void()>::iterator:  " << sizeof(sigc::signal<void()>::iterator) << std::endl;
     std::cout << "  connection:              " << sizeof(sigc::connection) << std::endl;
 
     std::cout << std::endl << "sizes of internal classes:" << std::endl;
@@ -48,4 +48,4 @@ int main(int argc, char* argv[])
     std::cout << "  signal_impl:             " << sizeof(sigc::internal::signal_impl) << std::endl;
   }
   return util->get_result_and_delete_instance() ? EXIT_SUCCESS : EXIT_FAILURE;
-}
\ No newline at end of file
+}
