@@ -39,18 +39,6 @@ public:
 };
 
 void test_simple()
-{
-  // simple test
-  sigc::slot<void,int> s1 = foo();
-  s1(1);
-  util->check_result(result_stream, "foo(int 1)");
-
-  s1 = foo();
-  s1(2);
-  util->check_result(result_stream, "foo(int 2)");
-}
-
-void test_std_function_style_syntax()
 {
   // simple test
   sigc::slot<void(int)> s1 = foo();
@@ -65,7 +53,7 @@ void test_std_function_style_syntax()
 void test_implicit_conversion()
 {
   // test implicit conversion
-  sigc::slot<void,char> s2 = foo();
+  sigc::slot<void(char)> s2 = foo();
   s2(3);
   util->check_result(result_stream, "foo(int 3)");
 }
@@ -73,7 +61,7 @@ void test_implicit_conversion()
 void test_reference()
 {
   // test reference
-  sigc::slot<void,std::string&> sl1 = foo();
+  sigc::slot<void(std::string&)> sl1 = foo();
   std::string str("guest book");
   sl1(str);
   result_stream << str;
@@ -84,8 +72,8 @@ void test_operator_equals()
 {
   // test operator=
   std::string str = "guest book";
-  sigc::slot<void,std::string&> sl1 = foo();
-  sigc::slot<void,std::string&> sl2;
+  sigc::slot<void(std::string&)> sl1 = foo();
+  sigc::slot<void(std::string&)> sl2;
   sl2 = sl1;
   sl1 = sl2;
   sl1(str);
@@ -96,8 +84,8 @@ void test_operator_equals()
 void test_copy_ctor()
 {
   // test copy ctor
-  sigc::slot<void,int> s1 = foo();
-  sigc::slot<void,int> s1_clone(s1);
+  sigc::slot<void(int)> s1 = foo();
+  sigc::slot<void(int)> s1_clone(s1);
   s1_clone(4);
   util->check_result(result_stream, "foo(int 4)");
 }
@@ -112,7 +100,6 @@ int main(int argc, char* argv[])
     return util->get_result_and_delete_instance() ? EXIT_SUCCESS : EXIT_FAILURE;
 
   test_simple();
-  test_std_function_style_syntax();
   test_implicit_conversion();
   test_reference();
   test_operator_equals();
