@@ -57,11 +57,11 @@ int main(int argc, char* argv[])
   if (!util->check_command_args(argc, argv))
     return util->get_result_and_delete_instance() ? EXIT_SUCCESS : EXIT_FAILURE;
 
-  sigc::slot<void> sl;
+  sigc::slot<void()> sl;
   {
     my_class t;
     t.i = 10;
-    sl = sigc::mem_fun(&t, &my_class::foo);
+    sl = sigc::mem_fun(t, &my_class::foo);
     sl();
     util->check_result(result_stream, "10");
 
@@ -70,7 +70,7 @@ int main(int argc, char* argv[])
     t2.i = 15;
     result_stream.clear();
 
-    sl = sigc::mem_fun(&t2, &my_class::foo);
+    sl = sigc::mem_fun(t2, &my_class::foo);
 
     sl();
     util->check_result(result_stream, "15");
